"use server";

import { requestGetFetch, requestPostFetch } from "@/utils/fetch";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";

export async function getBatches(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join('&');

    const path = 'v1/batches' + `${queryString ? `?${queryString}` : ''}`;

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || [];
  } catch (error) {
    throw error;
  }
}


export async function viewBatches(id: number) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/batches${id ? `/${id}` : ""}`;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || [];
  } catch (error) {
    throw error;
  }
}

export async function createBatch(formData: FormData) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const response = await requestPostFetch({
      path: `v1/batches`,
      data: formData,
      token: token,
    });
    return response;
  } catch (error: any) {
    throw new Error(error.message);
  }
}

export async function deleteBatch(id: number) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/batches/${id}`;
    const response = await requestGetFetch({
      path,
      options: {
        method: "DELETE",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    throw error;
  }
}